ROM core - monitoring engine, state management, display, and build cache
Re-exports
pub use error::Result;pub use error::RomError;pub use monitor::Monitor;pub use types::Config;pub use types::InputMode;
Modules
- cache
- display
- Display rendering for ROM
- error
- Error types for ROM
- icons
- Icon sets for ROM display output.
- monitor
- Monitor module for orchestrating state updates and display rendering
- state
- State management for ROM
- types
- Core types for ROM
- update
- State update logic for processing nix messages
Functions
- create_
monitor - Create a new monitor instance with the given configuration.
- monitor_
stream - Monitor a stream of nix output and display enhanced progress information.