BuildReportCache

Struct BuildReportCache 

pub struct BuildReportCache { /* private fields */ }
Build report cache for CSV persistence

Implementations

Source

impl BuildReportCache

pub const fn new(cache_path: PathBuf) -> Self

Create a new cache instance with the given path

pub fn default_cache_path() -> PathBuf

Get the default cache file path

pub fn load(&self) -> HashMap<(String, String), Vec<BuildReport>>

Load build reports from CSV

Returns empty HashMap if file doesn’t exist or parsing fails

pub fn save( &self, reports: &HashMap<(String, String), Vec<BuildReport>>, ) -> Result<(), Error>

Save build reports to CSV

Merges with existing reports and enforces history limit

pub fn calculate_median(reports: &[BuildReport]) -> Option<u64>

Calculate median build time from historical reports

Returns None if there are no reports

pub fn get_estimate( &self, reports: &HashMap<(String, String), Vec<BuildReport>>, host: &str, derivation_name: &str, ) -> Option<u64>

Get median build time for a specific derivation on a host